summaryrefslogtreecommitdiffstats
path: root/source/core/slang-test-tool-util.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/core/slang-test-tool-util.cpp')
-rw-r--r--source/core/slang-test-tool-util.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/core/slang-test-tool-util.cpp b/source/core/slang-test-tool-util.cpp
index 9a0ebe4f1..d362d7043 100644
--- a/source/core/slang-test-tool-util.cpp
+++ b/source/core/slang-test-tool-util.cpp
@@ -37,12 +37,12 @@ namespace Slang
}
}
/* static */bool TestToolUtil::hasDeferredStdLib(Index argc, const char*const* argv)
{
for (Index i = 0; i < argc; ++i)
{
UnownedStringSlice option(argv[i]);
- if (option == "-load-stdlib" || option == "-compile-stdlib")
+ if (option == "-load-core-module" || option == "-compile-core-module")
{
return true;
}
@@ -37,12 +37,12 @@ namespace Slang
}
}
-/* static */bool TestToolUtil::hasDeferredStdLib(Index argc, const char*const* argv)
+/* static */bool TestToolUtil::hasDeferredCoreModule(Index argc, const char*const* argv)
{
for (Index i = 0; i < argc; ++i)